vfbLib.parsers.ps.PostScriptInfoParser
======================================

.. currentmodule:: vfbLib.parsers.ps

.. autoclass:: PostScriptInfoParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PostScriptInfoParser.__init__
      ~PostScriptInfoParser.parse
      ~PostScriptInfoParser.parse_hex
      ~PostScriptInfoParser.read_double
      ~PostScriptInfoParser.read_doubles
      ~PostScriptInfoParser.read_float
      ~PostScriptInfoParser.read_floats
      ~PostScriptInfoParser.read_int16
      ~PostScriptInfoParser.read_int32
      ~PostScriptInfoParser.read_int8
      ~PostScriptInfoParser.read_str
      ~PostScriptInfoParser.read_str_all
      ~PostScriptInfoParser.read_uint16
      ~PostScriptInfoParser.read_uint32
      ~PostScriptInfoParser.read_uint8
      ~PostScriptInfoParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PostScriptInfoParser.encoding
      ~PostScriptInfoParser.master_count
      ~PostScriptInfoParser.stream
      ~PostScriptInfoParser.ttStemsH_count
      ~PostScriptInfoParser.ttStemsV_count
   
   